==============================
Redis cache backend for Django
==============================

Full featured redis cache backend for Django.

.. image:: https://img.shields.io/travis/niwinz/django-redis.svg?style=flat
    :target: https://travis-ci.org/niwinz/django-redis

.. image:: https://img.shields.io/pypi/v/django-redis.svg?style=flat
    :target: https://pypi.python.org/pypi/django-redis

.. image:: https://img.shields.io/pypi/dm/django-redis.svg?style=flat
    :target: https://pypi.python.org/pypi/django-redis


Documentation
-------------

http://niwinz.github.io/django-redis/latest/


How to install
--------------

Run ``python setup.py install`` to install,
or place ``django_redis`` on your Python path.

You can also install it with: ``pip install django-redis``
